@@ -1,4 +1,4 @@
-CREATE OR REPLACE FUNCTION pgpool_regclass(cstring)
+CREATE OR REPLACE FUNCTION pg_catalog.pgpool_regclass(cstring)
 RETURNS oid
 AS '$libdir/pgpool-regclass', 'pgpool_regclass'
 LANGUAGE C STRICT;
